@@ -8,6 +8,7 @@
 #include "devilspie-action-layer.h"
 #include "devilspie-action-decorate.h"
 #include "devilspie-action-savegeometry.h"
+#include "devilspie-action-setgeometry.h"
 #include "devilspie-action-setworkspace.h"
 #include "devilspie-action-resize.h"
 #include "devilspie-action-debug.h"
@@ -21,6 +22,7 @@ void flurb_init(void) {
   devilspie_action_decorate_get_type();
   devilspie_action_layer_get_type();
   devilspie_action_savegeometry_get_type();
+  devilspie_action_setgeometry_get_type();
   devilspie_action_setworkspace_get_type();
   devilspie_action_resize_get_type();
   devilspie_action_debug_get_type();
